ChiantiPy\.core\.tests package
==============================

Submodules
----------

ChiantiPy\.core\.tests\.test\_Continuum module
----------------------------------------------

.. automodule:: ChiantiPy.core.tests.test_Continuum
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.tests\.test\_Ion module
----------------------------------------

.. automodule:: ChiantiPy.core.tests.test_Ion
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.tests\.test\_Ioneq module
------------------------------------------

.. automodule:: ChiantiPy.core.tests.test_Ioneq
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.tests\.test\_Spectrum module
---------------------------------------------

.. automodule:: ChiantiPy.core.tests.test_Spectrum
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ChiantiPy.core.tests
    :members:
    :undoc-members:
    :show-inheritance:
